netapp_ontap.resources.role_privilege API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.role_privilege`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

A role can comprise of multiple tuples and each tuple consists of the REST API path and its access level. These APIs can be used to retrieve and modify the access level or delete one of the constituent REST API paths within a role.

The role can be SVM-scoped or cluster-scoped.

Specify the owner UUID and the role name in the URI path. The owner UUID corresponds to the UUID of the SVM for which the role has been created and can be obtained from the response body of a GET request performed on one of the following APIs: /api/security/roles for all roles /api/security/roles/?scope=svm for SVM-scoped roles /api/security/roles/?owner.name= for roles in a specific SVM This API response contains the complete URI for each tuple of the role and can be used for GET, PATCH, or DELETE operations.

Note: The access level for paths in pre-defined roles cannot be updated.

## Examples

### Updating the access level for a path in the privilege tuple of an existing role

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import RolePrivilege

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = RolePrivilege("svm_role1", path="/api/protocols")
        resource.access = "all"
        resource.patch()

### Retrieving the access level for a path in the privilege tuple of an existing role

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import RolePrivilege

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = RolePrivilege("svm_role1", path="/api/protocols")
        resource.get()
        print(resource)

Try it out

    RolePrivilege(
        {
            "_links": {
                "self": {
                    "href": "/api/security/roles/aaef7c38-4bd3-11e9-b238-0050568e2e25/svm_role1/privileges/%2Fapi%2Fprotocols"
                }
            },
            "access": "all",
            "path": "/api/protocols",
        }
    )

### Deleting a privilege tuple from an existing role

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import RolePrivilege

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = RolePrivilege("svm_role1", path="/api/protocols")
        resource.delete()

## Classes

`class RolePrivilege (*args, **kwargs)`

  A tuple containing the REST endpoint and the access level assigned to that endpoint.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves privilege details of the specified role.

    ### Related ONTAP commands

    - `security login rest-role show`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges`
    - `DOC /security/roles`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a privilege tuple (of REST URI and its access level) from the role.

    ### Required parameters

    - `owner.uuid` - UUID of the SVM which houses this role.
    - `name` - Name of the role to be updated.
    - `path` - Constituent REST API path to be deleted from this role.

    ### Related ONTAP commands

    - `security login rest-role delete`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges/{path}`
    - `DOC /security/roles`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves privilege details of the specified role.

    ### Related ONTAP commands

    - `security login rest-role show`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges`
    - `DOC /security/roles`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves privilege details of the specified role.

    ### Related ONTAP commands

    - `security login rest-role show`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges`
    - `DOC /security/roles`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the privilege level for a REST API path.

    ### Required parameters

    - `owner.uuid` - UUID of the SVM that houses this role.
    - `name` - Name of the role to be updated.
    - `path` - Constituent REST API path whose access level has to be updated.
    - `access` - Access level for the path (one of "all", "readonly", or "none")

    ### Related ONTAP commands

    - `security login rest-role modify`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges/{path}`
    - `DOC /security/roles`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a privilege tuple (of REST URI and its access level) from the role.

    ### Required parameters

    - `owner.uuid` - UUID of the SVM which houses this role.
    - `name` - Name of the role to be updated.
    - `path` - Constituent REST API path to be deleted from this role.

    ### Related ONTAP commands

    - `security login rest-role delete`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges/{path}`
    - `DOC /security/roles`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the privilege level for a REST API path for the specified role.

    ### Related ONTAP commands

    - `security login rest-role show`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges/{path}`
    - `DOC /security/roles`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the privilege level for a REST API path.

    ### Required parameters

    - `owner.uuid` - UUID of the SVM that houses this role.
    - `name` - Name of the role to be updated.
    - `path` - Constituent REST API path whose access level has to be updated.
    - `access` - Access level for the path (one of "all", "readonly", or "none")

    ### Related ONTAP commands

    - `security login rest-role modify`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges/{path}`
    - `DOC /security/roles`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Adds a privilege tuple (of REST URI and its access level) to an existing role.

    ### Required parameters

    - `owner.uuid` - UUID of the SVM that houses this role.
    - `name` - Name of the role to be updated.
    - `path` - REST URI path (example: "/api/storage/volumes").
    - `access` - Desired access level for the REST URI path (one of "all", "readonly" or "none").

    ### Related ONTAP commands

    - `security login rest-role create`

    ### Learn more

    - `DOC /security/roles/{owner.uuid}/{name}/privileges`
    - `DOC /security/roles`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class RolePrivilegeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the RolePrivilege object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `access GET POST PATCH`

    The access field of the role_privilege.

  `links GET`

    The links field of the role_privilege.

  `path GET POST`

    REST URI/endpoint

    Example: /api/storage/volumes